This function computes the coefficient of variation of the values in x. If na.rm is TRUE then missing values are removed before computation proceeds.
Usage
cv(x, percentual = TRUE, ...)
Arguments
- x
a numeric vector or an R object but not a factor coercible to numeric by as.double(x).
- percentual
logical; if TRUE (default), the coefficient of variation is returned in %.
- ...
further arguments passed to or from other methods.
Value
the coefficient of variation